package jalview.io;

import javax.swing.filechooser.*;
import java.io.File;
import java.util.*;

public class JalviewFileFilter extends FileFilter
{
      private static String TYPE_UNKNOWN = "Type Unknown";
      private static String HIDDEN_FILE = "Hidden File";
      public static Hashtable suffixHash = new Hashtable();

      private Hashtable filters = null;
      private String description = "no description";
      private String fullDescription = "full description";
      private boolean useExtensionsInDescription = true;


      public JalviewFileFilter(String extension, String description) {

       StringTokenizer st = new StringTokenizer(extension, ",");
       while(st.hasMoreElements())
       {
         addExtension(st.nextToken().trim());
       }
       setDescription(description);
      }

      public JalviewFileFilter(String[] filts) {
          this(filts, null);
      }

      public String getAcceptableExtension()
      {
        return filters.keys().nextElement().toString();
      }

      public JalviewFileFilter(String[] filts, String description) {
          for (int i = 0; i < filts.length; i++) {
              // add filters one by one
              addExtension(filts[i]);
          }
           if(description!=null) setDescription(description);
      }

      // takes account of the fact that database is a directory
      public boolean accept(File f) {
          if(f != null) {
              String extension = getExtension(f);
              if(f.isDirectory()) {
                 if(extension == null || extension.equals("")) {
                    return true;
                 } else {
                    if(filters.get(getExtension(f)) != null) {
                       return true;
                    }
                 }
              }
              if(extension != null && filters.get(getExtension(f)) != null) {
                  return true;
              }
          }
          return false;
      }

       public String getExtension(File f) {
          if(f != null) {
              String filename = f.getName();
              int i = filename.lastIndexOf('.');
              if(i>0 && i<filename.length()-1) {
                  return filename.substring(i+1).toLowerCase();
              };
          }
          return "";
      }

      public void addExtension(String extension) {
          if(filters == null) {
              filters = new Hashtable(5);
          }
          filters.put(extension.toLowerCase(), this);
          fullDescription = null;
      }


      public String getDescription() {
          if(fullDescription == null) {
              if(description == null || isExtensionListInDescription()) {
                   fullDescription = description==null ? "(" : description + " (";
                  // build the description from the extension list
                  Enumeration extensions = filters.keys();
                  if(extensions != null) {
                      fullDescription += "." + (String) extensions.nextElement();
                      while (extensions.hasMoreElements()) {
                          fullDescription += ", " + (String) extensions.nextElement();
                      }
                  }
                  fullDescription += ")";
              } else {
                  fullDescription = description;
              }
          }
          return fullDescription;
      }

      public void setDescription(String description) {
          this.description = description;
          fullDescription = null;
      }

      public void setExtensionListInDescription(boolean b) {
          useExtensionsInDescription = b;
          fullDescription = null;
      }

      public boolean isExtensionListInDescription() {
          return useExtensionsInDescription;
      }
  }
